@@ -41,6 +41,14 @@ def garbage_collect():
     if os.path.exists(os.path.join(os.getcwd(), "nbeats_weights")):
         shutil.rmtree(os.path.join(os.getcwd(), "nbeats_weights"))
 
+
+def get_run_id(output_dir):
+        # Get the most recent run
+        run_dirs = [os.path.join(output_dir, f) for f in os.listdir(output_dir)]
+        output_dir = sorted(run_dirs, key=lambda x: os.path.getmtime(x), reverse=True)[0]
+
+        return output_dir
+
 def prerun_error_check():
     if len(sys.argv) < 6 or len(sys.argv) > 7:
         arg_err_str = "Incorrect number of arguments provided. Required arguments: \n\t-Input Directory \n\t-Output Directory \n\t-Timeout(in minutes) \n\t-Number of CPU cores \n\t-D3M Problem Path (please refer to AutonML's documentation for more details \n\n Optional arguments \n\t-D3M Static directory: stores weight files\n"
@@ -87,19 +95,18 @@ def main_run():
     fit_and_evaluate(output_dir)
 
     # Save environment variables in a file
-    for search_dir in os.listdir(sys.argv[2]):
-        search_dir_path = os.path.join(sys.argv[2], search_dir)
-        filepath = os.path.join(search_dir_path, 'environment_variables.json')
-        
-        env_dict = {}
-        env_dict['D3MINPUTDIR'] = os.environ['D3MINPUTDIR']
-        env_dict['D3MSTATICDIR'] = os.environ['D3MSTATICDIR']
-        env_dict['D3MOUTPUTDIR'] = os.environ['D3MOUTPUTDIR']
-        env_dict['D3MTIMEOUT'] = os.environ['D3MTIMEOUT']
-        env_dict['D3MCPU'] = (int)(os.environ['D3MCPU'])
+    search_dir_path = get_run_id(sys.argv[2])
+    filepath = os.path.join(search_dir_path, 'environment_variables.json')
+    
+    env_dict = {}
+    env_dict['D3MINPUTDIR'] = os.environ['D3MINPUTDIR']
+    env_dict['D3MSTATICDIR'] = os.environ['D3MSTATICDIR']
+    env_dict['D3MOUTPUTDIR'] = os.environ['D3MOUTPUTDIR']
+    env_dict['D3MTIMEOUT'] = os.environ['D3MTIMEOUT']
+    env_dict['D3MCPU'] = (int)(os.environ['D3MCPU'])
 
-        with open(filepath, "w") as fp:
-            json.dump(env_dict, fp)
+    with open(filepath, "w") as fp:
+        json.dump(env_dict, fp)
 
     # Garbage collect any leftover intermediate variables
     garbage_collect()
